@@ -37,3 +37,20 @@ class DataContextKey(object, metaclass=ABCMeta):
 
     def __repr__(self):
         return self.__class__.__name__ + "::" + "/".join(self.to_tuple())
+
+
+class StringKey(DataContextKey):
+    """A simple DataContextKey with just a single string value"""
+
+    def __init__(self, key):
+        self._key = key
+
+    def to_tuple(self):
+        return (self._key,)
+
+    def to_fixed_length_tuple(self):
+        return self.to_tuple()
+
+    @classmethod
+    def from_fixed_length_tuple(cls, tuple_):
+        return cls.from_tuple(tuple_)
