@@ -1,5 +1,6 @@
 import copy
 import datetime
+import decimal
 import inspect
 import json
 import logging
@@ -9,6 +10,10 @@ import warnings
 from collections import Counter, defaultdict, namedtuple
 from collections.abc import Hashable
 from functools import wraps
+from typing import List
+
+from dateutil.parser import parse
+from marshmallow import ValidationError
 
 from great_expectations import __version__ as ge_version
 from great_expectations.core import (
@@ -16,18 +21,16 @@ from great_expectations.core import (
     ExpectationSuite,
     ExpectationSuiteValidationResult,
     ExpectationValidationResult,
+    RunIdentifier,
     expectationSuiteSchema,
 )
+from great_expectations.core.evaluation_parameters import build_evaluation_parameters
 from great_expectations.core.id_dict import BatchKwargs
-from great_expectations.data_asset.evaluation_parameters import (
-    build_evaluation_parameters,
-)
 from great_expectations.data_asset.util import (
     parse_result_format,
     recursively_convert_to_json_serializable,
 )
 from great_expectations.exceptions import GreatExpectationsError
-from marshmallow import ValidationError
 
 logger = logging.getLogger(__name__)
 logging.captureWarnings(True)
@@ -69,7 +72,7 @@ class DataAsset(object):
                 "Autoinspect_func is no longer supported; use a profiler instead (migration is easy!).",
                 category=DeprecationWarning,
             )
-        super(DataAsset, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._config = {"interactive_evaluation": interactive_evaluation}
         self._initialize_expectations(
             expectation_suite=expectation_suite,
@@ -219,16 +222,24 @@ class DataAsset(object):
                 expectation_args = copy.deepcopy(all_args)
 
                 if self._expectation_suite.evaluation_parameters:
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation_args,
                         self._expectation_suite.evaluation_parameters,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
                 else:
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation_args,
                         None,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
 
                 # Construct the expectation_config object
@@ -271,18 +282,20 @@ class DataAsset(object):
                 # If validate has set active_validation to true, then we do not save the config to avoid
                 # saving updating expectation configs to the same suite during validation runs
                 if self._active_validation is True:
-                    pass
+                    stored_config = expectation_config
                 else:
                     # Append the expectation to the config.
-                    self._append_expectation(expectation_config)
+                    stored_config = self._expectation_suite.add_expectation(
+                        expectation_config
+                    )
 
                 if include_config:
-                    return_obj.expectation_config = copy.deepcopy(expectation_config)
+                    return_obj.expectation_config = copy.deepcopy(stored_config)
 
                 # If there was no interactive evaluation, success will not have been computed.
                 if return_obj.success is not None:
                     # Add a "success" object to the config
-                    expectation_config.success_on_last_run = return_obj.success
+                    stored_config.success_on_last_run = return_obj.success
 
                 if catch_exceptions:
                     return_obj.exception_info = {
@@ -291,6 +304,11 @@ class DataAsset(object):
                         "exception_traceback": exception_traceback,
                     }
 
+                if len(substituted_parameters) > 0:
+                    if meta is None:
+                        meta = dict()
+                    meta["substituted_parameters"] = substituted_parameters
+
                 # Add meta to return object
                 if meta is not None:
                     return_obj.meta = meta
@@ -367,142 +385,59 @@ class DataAsset(object):
 
     def append_expectation(self, expectation_config):
         """This method is a thin wrapper for ExpectationSuite.append_expectation"""
-        self._expectation_suite.append_expectation(expectation_config)
-
-    def _append_expectation(self, expectation_config):
-        """This method
-
-        This method should become a thin wrapper for ExpectationSuite.append_expectation
-
-        Included for backwards compatibility.
-        """
-        """Appends an expectation to `DataAsset._expectation_suite` and drops existing expectations of the same type.
-
-           If `expectation_config` is a column expectation, this drops existing expectations that are specific to \
-           that column and only if it is the same expectation type as `expectation_config`. Otherwise, if it's not a \
-           column expectation, this drops existing expectations of the same type as `expectation config`. \
-           After expectations of the same type are dropped, `expectation_config` is appended to \
-           `DataAsset._expectation_suite`.
-
-           Args:
-               expectation_config (json): \
-                   The JSON-serializable expectation to be added to the DataAsset expectations in `_expectation_suite`.
-
-           Notes:
-               May raise future errors once json-serializable tests are implemented to check for correct arg formatting
-
-        """
-        expectation_type = expectation_config.expectation_type
-
-        # Test to ensure the new expectation is serializable.
-        # FIXME: If it's not, are we sure we want to raise an error?
-        # FIXME: Should we allow users to override the error?
-        # FIXME: Should we try to convert the object using something like recursively_convert_to_json_serializable?
-        # json.dumps(expectation_config)
-
-        # Drop existing expectations with the same expectation_type.
-        # For column_expectations, _append_expectation should only replace expectations
-        # where the expectation_type AND the column match
-        # !!! This is good default behavior, but
-        # !!!    it needs to be documented, and
-        # !!!    we need to provide syntax to override it.
-
-        if "column" in expectation_config.kwargs:
-            column = expectation_config.kwargs["column"]
-
-            self._expectation_suite.expectations = [
-                f
-                for f in filter(
-                    lambda exp: (exp.expectation_type != expectation_type)
-                    or ("column" in exp.kwargs and exp.kwargs["column"] != column),
-                    self._expectation_suite.expectations,
-                )
-            ]
-        else:
-            self._expectation_suite.expectations = [
-                f
-                for f in filter(
-                    lambda exp: exp.expectation_type != expectation_type,
-                    self._expectation_suite.expectations,
-                )
-            ]
-
-        self._expectation_suite.append_expectation(expectation_config)
-
-    def _copy_and_clean_up_expectation(
-        self,
-        expectation,
-        discard_result_format_kwargs=True,
-        discard_include_config_kwargs=True,
-        discard_catch_exceptions_kwargs=True,
-    ):
-        """This method is a thin wrapper for ExpectationSuite._copy_and_clean_up_expectation"""
-        return self._expectation_suite._copy_and_clean_up_expectation(
-            expectation=expectation,
-            discard_result_format_kwargs=discard_result_format_kwargs,
-            discard_include_config_kwargs=discard_include_config_kwargs,
-            discard_catch_exceptions_kwargs=discard_catch_exceptions_kwargs,
-        )
-
-    def _copy_and_clean_up_expectations_from_indexes(
-        self,
-        match_indexes,
-        discard_result_format_kwargs=True,
-        discard_include_config_kwargs=True,
-        discard_catch_exceptions_kwargs=True,
-    ):
-        """This method is a thin wrapper for ExpectationSuite._copy_and_clean_up_expectations_from_indexes"""
-        return self._expectation_suite._copy_and_clean_up_expectations_from_indexes(
-            match_indexes=match_indexes,
-            discard_result_format_kwargs=discard_result_format_kwargs,
-            discard_include_config_kwargs=discard_include_config_kwargs,
-            discard_catch_exceptions_kwargs=discard_catch_exceptions_kwargs,
+        warnings.warn(
+            "append_expectation is deprecated, and will be removed in a future release. "
+            + "Please use ExpectationSuite.add_expectation instead.",
+            DeprecationWarning,
         )
+        self._expectation_suite.append_expectation(expectation_config)
 
     def find_expectation_indexes(
-        self, expectation_type=None, column=None, expectation_kwargs=None
-    ):
+        self,
+        expectation_configuration: ExpectationConfiguration,
+        match_type: str = "domain",
+    ) -> List[int]:
         """This method is a thin wrapper for ExpectationSuite.find_expectation_indexes"""
+        warnings.warn(
+            "find_expectation_indexes is deprecated, and will be removed in a future release. "
+            + "Please use ExpectationSuite.find_expectation_indexes instead.",
+            DeprecationWarning,
+        )
         return self._expectation_suite.find_expectation_indexes(
-            expectation_type=expectation_type,
-            column=column,
-            expectation_kwargs=expectation_kwargs,
+            expectation_configuration=expectation_configuration, match_type=match_type
         )
 
     def find_expectations(
         self,
-        expectation_type=None,
-        column=None,
-        expectation_kwargs=None,
-        discard_result_format_kwargs=True,
-        discard_include_config_kwargs=True,
-        discard_catch_exceptions_kwargs=True,
-    ):
+        expectation_configuration: ExpectationConfiguration,
+        match_type: str = "domain",
+    ) -> List[ExpectationConfiguration]:
         """This method is a thin wrapper for ExpectationSuite.find_expectations()"""
+        warnings.warn(
+            "find_expectations is deprecated, and will be removed in a future release. "
+            + "Please use ExpectationSuite.find_expectation_indexes instead.",
+            DeprecationWarning,
+        )
         return self._expectation_suite.find_expectations(
-            expectation_type=expectation_type,
-            column=column,
-            expectation_kwargs=expectation_kwargs,
-            discard_result_format_kwargs=discard_result_format_kwargs,
-            discard_include_config_kwargs=discard_include_config_kwargs,
-            discard_catch_exceptions_kwargs=discard_catch_exceptions_kwargs,
+            expectation_configuration=expectation_configuration, match_type=match_type
         )
 
     def remove_expectation(
         self,
-        expectation_type=None,
-        column=None,
-        expectation_kwargs=None,
-        remove_multiple_matches=False,
-        dry_run=False,
-    ):
+        expectation_configuration: ExpectationConfiguration,
+        match_type: str = "domain",
+        remove_multiple_matches: bool = False,
+    ) -> List[ExpectationConfiguration]:
         """This method is a thin wrapper for ExpectationSuite.remove()"""
+        warnings.warn(
+            "DataAsset.remove_expectations is deprecated, and will be removed in a future release. "
+            + "Please use ExpectationSuite.remove_expectation instead.",
+            DeprecationWarning,
+        )
         return self._expectation_suite.remove_expectation(
-            expectation_type=expectation_type,
-            column=column,
-            expectation_kwargs=expectation_kwargs,
+            expectation_configuration=expectation_configuration,
+            match_type=match_type,
             remove_multiple_matches=remove_multiple_matches,
-            dry_run=dry_run,
         )
 
     def set_config_value(self, key, value):
@@ -532,8 +467,8 @@ class DataAsset(object):
         if any(res):
             for item in res:
                 self.remove_expectation(
-                    expectation_type=item.expectation_config.expectation_type,
-                    expectation_kwargs=item.expectation_config["kwargs"],
+                    expectation_configuration=item.expectation_config,
+                    match_type="runtime",
                 )
             warnings.warn("Removed %s expectations that were 'False'" % len(res))
 
@@ -601,6 +536,7 @@ class DataAsset(object):
         discard_include_config_kwargs=True,
         discard_catch_exceptions_kwargs=True,
         suppress_warnings=False,
+        suppress_logging=False,
     ):
         """Returns _expectation_config as a JSON object, and perform some cleaning along the way.
 
@@ -613,6 +549,10 @@ class DataAsset(object):
                 In returned expectation objects, suppress the `include_config` parameter. Defaults to `True`.
             discard_catch_exceptions_kwargs (boolean): \
                 In returned expectation objects, suppress the `catch_exceptions` parameter.  Defaults to `True`.
+            suppress_warnings (boolean): \
+                If true, do not include warnings in logging information about the operation.
+            suppress_logging (boolean): \
+                If true, do not create a log entry (useful when using get_expectation_suite programmatically)
 
         Returns:
             An expectation suite.
@@ -690,7 +630,8 @@ class DataAsset(object):
             settings_message += " settings filtered."
 
         expectation_suite.expectations = expectations
-        logger.info(message + settings_message)
+        if not suppress_logging:
+            logger.info(message + settings_message)
         return expectation_suite
 
     def save_expectation_suite(
@@ -760,6 +701,8 @@ class DataAsset(object):
         catch_exceptions=True,
         result_format=None,
         only_return_failures=False,
+        run_name=None,
+        run_time=None,
     ):
         """Generates a JSON-formatted report describing the outcome of all expectations.
 
@@ -769,9 +712,9 @@ class DataAsset(object):
             expectation_suite (json or None): \
                 If None, uses the expectations config generated with the DataAsset during the current session. \
                 If a JSON file, validates those expectations.
-            run_id (str): \
-                A string used to identify this validation result as part of a collection of validations. See \
-                DataContext for more information.
+            run_name (str): \
+                Used to identify this validation result as part of a collection of validations. \
+                See DataContext for more information.
             data_context (DataContext): \
                 A datacontext object to use as part of validation for binding evaluation parameters and \
                 registering validation results.
@@ -827,6 +770,31 @@ class DataAsset(object):
            AttributeError - if 'catch_exceptions'=None and an expectation throws an AttributeError
         """
         try:
+            validation_time = datetime.datetime.now(datetime.timezone.utc).strftime(
+                "%Y%m%dT%H%M%S.%fZ"
+            )
+
+            assert not (run_id and run_name) and not (
+                run_id and run_time
+            ), "Please provide either a run_id or run_name and/or run_time."
+            if isinstance(run_id, str) and not run_name:
+                warnings.warn(
+                    "String run_ids will be deprecated in the future. Please provide a run_id of type "
+                    "RunIdentifier(run_name=None, run_time=None), or a dictionary containing run_name "
+                    "and run_time (both optional). Instead of providing a run_id, you may also provide"
+                    "run_name and run_time separately.",
+                    DeprecationWarning,
+                )
+                try:
+                    run_time = parse(run_id)
+                except (ValueError, TypeError):
+                    pass
+                run_id = RunIdentifier(run_name=run_id, run_time=run_time)
+            elif isinstance(run_id, dict):
+                run_id = RunIdentifier(**run_id)
+            elif not isinstance(run_id, RunIdentifier):
+                run_id = RunIdentifier(run_name=run_name, run_time=run_time)
+
             self._active_validation = True
 
             # If a different validation data context was provided, override
@@ -899,20 +867,19 @@ class DataAsset(object):
             )
 
             # Warn if our version is different from the version in the configuration
-            try:
-                if (
-                    expectation_suite.meta["great_expectations.__version__"]
-                    != ge_version
-                ):
+            # TODO: Deprecate "great_expectations.__version__"
+            suite_ge_version = expectation_suite.meta.get(
+                "great_expectations_version"
+            ) or expectation_suite.meta.get("great_expectations.__version__")
+
+            if suite_ge_version:
+                if suite_ge_version != ge_version:
                     warnings.warn(
                         "WARNING: This configuration object was built using version %s of great_expectations, but "
                         "is currently being validated by version %s."
-                        % (
-                            expectation_suite.meta["great_expectations.__version__"],
-                            ge_version,
-                        )
+                        % (suite_ge_version, ge_version,)
                     )
-            except KeyError:
+            else:
                 warnings.warn(
                     "WARNING: No great_expectations version found in configuration object."
                 )
@@ -953,10 +920,14 @@ class DataAsset(object):
                         expectation.kwargs.update({"result_format": result_format})
 
                     # A missing parameter will raise an EvaluationParameterError
-                    evaluation_args = build_evaluation_parameters(
+                    (
+                        evaluation_args,
+                        substituted_parameters,
+                    ) = build_evaluation_parameters(
                         expectation.kwargs,
                         runtime_evaluation_parameters,
                         self._config.get("interactive_evaluation", True),
+                        self._data_context,
                     )
 
                     result = expectation_method(
@@ -1006,9 +977,6 @@ class DataAsset(object):
 
             expectation_suite_name = expectation_suite.expectation_suite_name
 
-            if run_id is None:
-                run_id = datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")
-
             result = ExpectationSuiteValidationResult(
                 results=results,
                 success=statistics.success,
@@ -1020,12 +988,13 @@ class DataAsset(object):
                 },
                 evaluation_parameters=runtime_evaluation_parameters,
                 meta={
-                    "great_expectations.__version__": ge_version,
+                    "great_expectations_version": ge_version,
                     "expectation_suite_name": expectation_suite_name,
                     "run_id": run_id,
                     "batch_kwargs": self.batch_kwargs,
                     "batch_markers": self.batch_markers,
                     "batch_parameters": self.batch_parameters,
+                    "validation_time": validation_time,
                 },
             )
 
@@ -1190,9 +1159,12 @@ class DataAsset(object):
                     )
                 ]
             except TypeError:
-                partial_unexpected_counts = [
-                    "partial_exception_counts requires a hashable type"
-                ]
+                partial_unexpected_counts = []
+                if "details" not in return_obj["result"]:
+                    return_obj["result"]["details"] = {}
+                return_obj["result"]["details"][
+                    "partial_unexpected_counts_error"
+                ] = "partial_unexpected_counts requested, but requires a hashable type"
             finally:
                 return_obj["result"].update(
                     {
@@ -1238,17 +1210,23 @@ class DataAsset(object):
         Returns:
             success (boolean), percent_success (float)
         """
+        if isinstance(success_count, decimal.Decimal):
+            raise ValueError(
+                "success_count must not be a decimal; check your db configuration"
+            )
+
+        if isinstance(nonnull_count, decimal.Decimal):
+            raise ValueError(
+                "nonnull_count must not be a decimal; check your db configuration"
+            )
 
         if nonnull_count > 0:
-            # percent_success = float(success_count)/nonnull_count
             percent_success = success_count / nonnull_count
 
             if mostly is not None:
                 success = bool(percent_success >= mostly)
-
             else:
                 success = bool(nonnull_count - success_count == 0)
-
         else:
             success = True
             percent_success = None
@@ -1277,7 +1255,7 @@ class DataAsset(object):
             define custom classes, etc. To use developed expectations from the command-line tool, you will still need \
             to define custom classes, etc.
 
-            Check out :ref:`custom_expectations_reference` for more information.
+            Check out :ref:`how_to_guides__creating_and_editing_expectations__how_to_create_custom_expectations` for more information.
         """
 
         argspec = inspect.getfullargspec(function)[0][1:]
