@@ -55,15 +55,34 @@ class MetaPandasDataset(Dataset):
         @cls.expectation(argspec)
         @wraps(func)
         def inner_wrapper(
-            self, column, mostly=None, result_format=None, *args, **kwargs
+            self,
+            column,
+            mostly=None,
+            result_format=None,
+            row_condition=None,
+            condition_parser=None,
+            *args,
+            **kwargs
         ):
 
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
             result_format = parse_result_format(result_format)
+            if row_condition:
+                if condition_parser not in ["python", "pandas"]:
+                    raise ValueError(
+                        "condition_parser is required when setting a row_condition,"
+                        " and must be 'python' or 'pandas'"
+                    )
+                else:
+                    data = self.query(
+                        row_condition, parser=condition_parser
+                    ).reset_index(drop=True)
+            else:
+                data = self
 
-            series = self[column]
+            series = data[column]
             if func.__name__ in [
                 "expect_column_values_to_not_be_null",
                 "expect_column_values_to_be_null",
@@ -161,6 +180,8 @@ class MetaPandasDataset(Dataset):
             mostly=None,
             ignore_row_if="both_values_are_missing",
             result_format=None,
+            row_condition=None,
+            condition_parser=None,
             *args,
             **kwargs
         ):
@@ -168,6 +189,9 @@ class MetaPandasDataset(Dataset):
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
+            if row_condition:
+                self = self.query(row_condition).reset_index(drop=True)
+
             series_A = self[column_A]
             series_B = self[column_B]
 
@@ -260,6 +284,8 @@ class MetaPandasDataset(Dataset):
             mostly=None,
             ignore_row_if="all_values_are_missing",
             result_format=None,
+            row_condition=None,
+            condition_parser=None,
             *args,
             **kwargs
         ):
@@ -267,6 +293,9 @@ class MetaPandasDataset(Dataset):
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
+            if row_condition:
+                self = self.query(row_condition).reset_index(drop=True)
+
             test_df = self[column_list]
 
             if ignore_row_if == "all_values_are_missing":
@@ -501,6 +530,8 @@ Notes:
         column,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -515,6 +546,8 @@ Notes:
         column,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -530,6 +563,8 @@ Notes:
         column,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -546,7 +581,8 @@ Notes:
         # Since we've now received the default arguments *before* the expectation decorator, we need to
         # ensure we only pass what we actually received. Hence, we'll use kwargs
         # mostly=None,
-        # result_format=None, include_config=None, catch_exceptions=None, meta=None
+        # result_format=None,
+        # row_condition=None, condition_parser=None, include_config=None, catch_exceptions=None, meta=None
     ):
         """
         The pandas implementation of this expectation takes kwargs mostly, result_format, include_config,
@@ -586,16 +622,21 @@ Notes:
 
             # First, if there is an existing expectation of this type, delete it. Then change the one we created to be
             # of the proper expectation_type
-            existing_expectations = self.find_expectation_indexes(
-                "expect_column_values_to_be_of_type", column
+            existing_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="expect_column_values_to_be_of_type",
+                    kwargs={"column": column},
+                )
             )
             if len(existing_expectations) == 1:
                 self._expectation_suite.expectations.pop(existing_expectations[0])
 
             # Now, rename the expectation we just added
-
-            new_expectations = self.find_expectation_indexes(
-                "_expect_column_values_to_be_of_type__aggregate", column
+            new_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="_expect_column_values_to_be_of_type__aggregate",
+                    kwargs={"column": column},
+                )
             )
             assert len(new_expectations) == 1
             old_config = self._expectation_suite.expectations[new_expectations[0]]
@@ -617,15 +658,21 @@ Notes:
 
             # First, if there is an existing expectation of this type, delete it. Then change the one we created to be
             # of the proper expectation_type
-            existing_expectations = self.find_expectation_indexes(
-                "expect_column_values_to_be_of_type", column
+            existing_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="expect_column_values_to_be_of_type",
+                    kwargs={"column": column},
+                )
             )
             if len(existing_expectations) == 1:
                 self._expectation_suite.expectations.pop(existing_expectations[0])
 
             # Now, rename the expectation we just added
-            new_expectations = self.find_expectation_indexes(
-                "_expect_column_values_to_be_of_type__map", column
+            new_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="_expect_column_values_to_be_of_type__map",
+                    kwargs={"column": column},
+                )
             )
             assert len(new_expectations) == 1
             old_config = self._expectation_suite.expectations[new_expectations[0]]
@@ -646,6 +693,8 @@ Notes:
         type_,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -717,6 +766,8 @@ Notes:
         type_,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -758,7 +809,8 @@ Notes:
         # Since we've now received the default arguments *before* the expectation decorator, we need to
         # ensure we only pass what we actually received. Hence, we'll use kwargs
         # mostly=None,
-        # result_format=None, include_config=None, catch_exceptions=None, meta=None
+        # result_format = None,
+        # row_condition=None, condition_parser=None, include_config=None, catch_exceptions=None, meta=None
     ):
         """
         The pandas implementation of this expectation takes kwargs mostly, result_format, include_config,
@@ -794,14 +846,20 @@ Notes:
 
             # First, if there is an existing expectation of this type, delete it. Then change the one we created to be
             # of the proper expectation_type
-            existing_expectations = self.find_expectation_indexes(
-                "expect_column_values_to_be_in_type_list", column
+            existing_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="expect_column_values_to_be_in_type_list",
+                    kwargs={"column": column},
+                )
             )
             if len(existing_expectations) == 1:
                 self._expectation_suite.expectations.pop(existing_expectations[0])
 
-            new_expectations = self.find_expectation_indexes(
-                "_expect_column_values_to_be_in_type_list__aggregate", column
+            new_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="_expect_column_values_to_be_in_type_list__aggregate",
+                    kwargs={"column": column},
+                )
             )
             assert len(new_expectations) == 1
             old_config = self._expectation_suite.expectations[new_expectations[0]]
@@ -825,15 +883,21 @@ Notes:
 
             # First, if there is an existing expectation of this type, delete it. Then change the one we created to be
             # of the proper expectation_type
-            existing_expectations = self.find_expectation_indexes(
-                "expect_column_values_to_be_in_type_list", column
+            existing_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="expect_column_values_to_be_in_type_list",
+                    kwargs={"column": column},
+                )
             )
             if len(existing_expectations) == 1:
                 self._expectation_suite.expectations.pop(existing_expectations[0])
 
             # Now, rename the expectation we just added
-            new_expectations = self.find_expectation_indexes(
-                "_expect_column_values_to_be_in_type_list__map", column
+            new_expectations = self._expectation_suite.find_expectation_indexes(
+                ExpectationConfiguration(
+                    expectation_type="_expect_column_values_to_be_in_type_list__map",
+                    kwargs={"column": column},
+                )
             )
             assert len(new_expectations) == 1
             old_config = self._expectation_suite.expectations[new_expectations[0]]
@@ -854,6 +918,8 @@ Notes:
         type_list,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -903,6 +969,8 @@ Notes:
         type_list,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -945,6 +1013,8 @@ Notes:
         mostly=None,
         parse_strings_as_datetimes=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -952,6 +1022,7 @@ Notes:
         if value_set is None:
             # Vacuously true
             return np.ones(len(column), dtype=np.bool_)
+
         if parse_strings_as_datetimes:
             parsed_value_set = self._parse_value_set(value_set)
         else:
@@ -968,6 +1039,8 @@ Notes:
         mostly=None,
         parse_strings_as_datetimes=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -992,6 +1065,8 @@ Notes:
         output_strftime_format=None,
         allow_cross_type_comparisons=None,
         mostly=None,
+        row_condition=None,
+        condition_parser=None,
         result_format=None,
         include_config=True,
         catch_exceptions=None,
@@ -1118,7 +1193,10 @@ Notes:
         column,
         strictly=None,
         parse_strings_as_datetimes=None,
+        output_strftime_format=None,
         mostly=None,
+        row_condition=None,
+        condition_parser=None,
         result_format=None,
         include_config=True,
         catch_exceptions=None,
@@ -1154,7 +1232,10 @@ Notes:
         column,
         strictly=None,
         parse_strings_as_datetimes=None,
+        output_strftime_format=None,
         mostly=None,
+        row_condition=None,
+        condition_parser=None,
         result_format=None,
         include_config=True,
         catch_exceptions=None,
@@ -1191,6 +1272,8 @@ Notes:
         min_value=None,
         max_value=None,
         mostly=None,
+        row_condition=None,
+        condition_parser=None,
         result_format=None,
         include_config=True,
         catch_exceptions=None,
@@ -1233,6 +1316,8 @@ Notes:
         value,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1247,6 +1332,8 @@ Notes:
         regex,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1261,6 +1348,8 @@ Notes:
         regex,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1276,6 +1365,8 @@ Notes:
         match_on="any",
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1301,6 +1392,8 @@ Notes:
         regex_list,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1320,6 +1413,8 @@ Notes:
         strftime_format,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1331,7 +1426,7 @@ Notes:
                 datetime.strftime(datetime.now(), strftime_format), strftime_format
             )
         except ValueError as e:
-            raise ValueError("Unable to use provided strftime_format. " + e.message)
+            raise ValueError("Unable to use provided strftime_format. " + str(e))
 
         def is_parseable_by_format(val):
             try:
@@ -1353,6 +1448,8 @@ Notes:
         column,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1379,6 +1476,8 @@ Notes:
         column,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1400,6 +1499,8 @@ Notes:
         json_schema,
         mostly=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1429,6 +1530,8 @@ Notes:
         p_value=0.05,
         params=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1476,6 +1579,8 @@ Notes:
         bootstrap_samples=None,
         bootstrap_sample_size=None,
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1585,6 +1690,8 @@ Notes:
         column_B,
         ignore_row_if="both_values_are_missing",
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1602,6 +1709,8 @@ Notes:
         allow_cross_type_comparisons=None,
         ignore_row_if="both_values_are_missing",
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1632,6 +1741,8 @@ Notes:
         value_pairs_set,
         ignore_row_if="both_values_are_missing",
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
@@ -1666,6 +1777,8 @@ Notes:
         column_list,
         ignore_row_if="all_values_are_missing",
         result_format=None,
+        row_condition=None,
+        condition_parser=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
